@@ -48,7 +48,7 @@ class TemplateVariables(object):
 class Media(TemplateVariables):
 
     def __init__(self, page, webalbum_media):
-        super(Media, self).__init__(page)
+        super().__init__(page)
         self.webalbum_media = webalbum_media
         self.media = webalbum_media.media
 
@@ -107,26 +107,12 @@ class Image(Media):
             tpl_values['image_date'] = img_date.strftime(_("on %d/%m/%Y at %H:%M"))
             tpl_values['image_datetime'] = img_date
 
-            image_info = self.media.info()
-            if image_info:
-                comment = image_info.get_comment()
-                if comment == '' or comment is None:
-                    tpl_values['comment'] = None
-                else:
-                    tpl_values['comment'] = self.page._do_not_escape(comment)
+            tpl_values.update(self.media.md)
+            tpl_values['comment'] = self.page._do_not_escape(tpl_values['comment'])
 
-                tpl_values['camera_name'] = image_info.get_camera_name()
-                tpl_values['lens_name'] = image_info.get_lens_name()
-                tpl_values['flash'] = image_info.get_flash()
-                tpl_values['exposure'] = image_info.get_exposure()
-                tpl_values['iso'] = image_info.get_iso()
-                tpl_values['fnumber'] = image_info.get_fnumber()
-                tpl_values['focal_length'] = image_info.get_focal_length()
-                tpl_values['authorship'] = image_info.get_authorship()
-                tpl_values['keywords'] = ', '.join(image_info.get_keywords())
-
-                if self.page.dir.config.get('webgal', 'keep-gps'):
-                    tpl_values['location'] = image_info.get_location()
+            if 'location' in tpl_values \
+            and not self.page.dir.config.get('webgal', 'keep-gps'):
+                del tpl_values['location']
 
         return tpl_values
 
@@ -154,7 +140,7 @@ def media_vars(page, webalbum_media):
 class SrcPath(TemplateVariables):
 
     def __init__(self, page, srcpath):
-        super(SrcPath, self).__init__(page)
+        super().__init__(page)
         self.srcpath = srcpath
 
     def should_be_flattened(self):
@@ -203,7 +189,7 @@ class SrcPath(TemplateVariables):
 class Webgal(SrcPath):
 
     def __init__(self, page, webgal):
-        super(Webgal, self).__init__(page, webgal.source_dir.path)
+        super().__init__(page, webgal.source_dir.path)
         self.webgal = webgal
 
     def info(self):
@@ -219,7 +205,7 @@ class Webgal(SrcPath):
         if 'album_name' not in dir_info:
             dir_info['album_name'] = self.webgal.source_dir.human_name
 
-        dirzip = self.webgal.pindex.dirzip()
+        dirzip = self.webgal.webassets.data['dirzip']
         if dirzip:
             archive_rel_dir = self.webgal.rel_path(self.page.dir.path)
             archive_rel_path = posixpath.join(archive_rel_dir,
